@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 66551 2011-01-03 22:08:38Z CJP $"
-__revision__ = "$Revision: 66551 $"
+__svnid__ = "$Id: Editra.py 66987 2011-02-21 18:37:54Z CJP $"
+__revision__ = "$Revision: 66987 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -31,6 +31,7 @@ if not hasattr(sys, 'frozen') and 'wx' not in sys.modules:
     import wxversion
     wxversion.ensureMinimal('2.8')
 
+import codecs
 import base64
 import locale
 import getopt
@@ -95,6 +96,11 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         # Disable debug popups
         wx.Log.EnableLogging(False)
+        # XXX: Temporary - disable assertions on OSX to work around 
+        #      upstream bug in drawing code "couldnt draw the rotated text"
+        if wx.Platform == '__WXMAC__':
+            self.SetAssertMode(wx.PYAPP_ASSERT_SUPPRESS)
+
         # Purge old logs
         logfile = dev_tool.EdLogFile()
         logfile.PurgeOldLogs(7)
@@ -206,8 +212,18 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             self.locale = None
 
         # Check and set encoding if necessary
-        if not profiler.Profile_Get('ENCODING'):
-            profiler.Profile_Set('ENCODING', locale.getpreferredencoding())
+        d_enc = profiler.Profile_Get('ENCODING')
+        if not d_enc:
+            profiler.Profile_Set('ENCODING', ed_txt.DEFAULT_ENCODING)
+        else:
+            # Ensure the default encoding is valid
+            # Fixes up older installs on some systems that may have an
+            # invalid encoding set.
+            try:
+                codecs.lookup(d_enc)
+            except (LookupError, TypeError):
+                self._log("[app][err] Resetting bad encoding: %s" % d_enc)
+                profiler.Profile_Set('ENCODING', ed_txt.DEFAULT_ENCODING)
 
         # Setup the Error Reporter
         if profiler.Profile_Get('REPORTER', 'bool', True):
@@ -424,6 +440,9 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname, line)
 
                 # Make sure the window is brought to the front
+                if wx.Platform == '__WXMSW__' and not window.IsIconized():
+                    # HACK to work around Raise not bring window to front
+                    window.Iconize(True)
                 if window.IsIconized():
                     window.Iconize(False)
                 window.Raise()
