@@ -16,8 +16,8 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 66365 2010-12-12 23:30:26Z CJP $"
-__revision__ = "$Revision: 66365 $"
+__cvsid__ = "$Id: pycomp.py 66879 2011-02-10 18:45:12Z CJP $"
+__revision__ = "$Revision: 66879 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -203,12 +203,16 @@ class PyCompleter(object):
             exec src in self.compldict
         except Exception, msg:
             dbg("[pycomp][err] src exec: %s" % msg)
+        else:
+            dbg("[pycomp][info] Successfully executed source code")
 
         for loc in scope.locals:
             try: 
                 exec loc in self.compldict
             except Exception, msg:
                 dbg("[pycomp][err] local exec %s [%s]" % (msg, loc))
+            else:
+                dbg("[pycomp][info] Successfully executed: %s" % loc)
 
     def get_arguments(self, func_obj):
         """Get the arguments of a given function obj
