@@ -14,12 +14,13 @@ Utility functions for managing and working with files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: fileutil.py 61040 2009-06-13 08:16:04Z CJP $"
-__revision__ = "$Revision: 61040 $"
+__svnid__ = "$Id: fileutil.py 66044 2010-11-05 23:13:22Z CJP $"
+__revision__ = "$Revision: 66044 $"
 
-__all__ = [ 'GetFileModTime', 'GetFileSize', 'GetUniqueName', 'MakeNewFile',
-            'MakeNewFolder', 'GetFileExtension', 'GetFileName', 'GetPathName',
-            'ResolveRealPath', 'IsLink', 'GetPathFromURI', 'PathExists']
+__all__ = [ 'GetAbsPath', 'GetFileExtension', 'GetFileModTime', 'GetFileName',
+            'GetFileSize', 'GetPathName', 'GetPathFromURI', 'GetUniqueName', 
+            'IsLink', 'MakeNewFile', 'MakeNewFolder', 'PathExists',
+            'ResolveRealPath', 'IsExecutable', 'Which']
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -36,6 +37,12 @@ if platform.system().lower() in ['windows', 'microsoft']:
         import win32com.client as win32client
     except ImportError:
         win32client = None
+
+    try:
+        # Check for win32api
+        import win32api
+    except ImportError:
+        win32api = None
 else:
     UNIX = True
 
@@ -57,6 +64,25 @@ def uri2path(func):
 
 #-----------------------------------------------------------------------------#
 
+@uri2path
+def GetAbsPath(path):
+    """Get the absolute path of a file of a file.
+    @param path: string
+    @return: string
+    @note: on windows if win32api is available short notation paths will be
+           converted to the proper long name.
+    
+    """
+    rpath = os.path.abspath(path)
+    # Resolve short path notation on Windows when possible
+    if WIN and win32api is not None and u"~" in rpath:
+        try:
+            rpath = win32api.GetLongPathNameW(rpath)
+        except Exception:
+            # Ignore errors from win32api calls
+            pass
+    return rpath
+
 def GetFileExtension(file_str):
     """Gets last atom at end of string as extension if
     no extension whole string is returned
@@ -144,6 +170,15 @@ def PathExists(path):
     """
     return os.path.exists(path)
 
+@uri2path
+def IsExecutable(path):
+    """Is the file at the given path an executable file
+    @param path: file path
+    @return: bool
+
+    """
+    return os.path.isfile(path) and os.access(path, os.X_OK)
+
 @uri2path
 def ResolveRealPath(link):
     """Return the real path of the link file
@@ -161,6 +196,23 @@ def ResolveRealPath(link):
         realpath = os.path.realpath(link)
     return realpath
 
+def Which(program):
+    """Find the path of the given executable
+    @param program: executable name (i.e 'python')
+    @return: executable path or None
+
+    """
+    # Check local directory first
+    if IsExecutable(program):
+        return program
+    else:
+        # Start looking on the $PATH
+        for path in os.environ["PATH"].split(os.pathsep):
+            exe_file = os.path.join(path, program)
+            if IsExecutable(exe_file):
+                return exe_file        
+    return None
+
 #-----------------------------------------------------------------------------#
 
 def GetUniqueName(path, name):
