@@ -61,11 +61,12 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 66451 2010-12-26 16:11:56Z CJP $"
-__revision__ = "$Revision: 66451 $"
+__svnid__ = "$Id: outbuff.py 66988 2011-02-22 02:21:05Z CJP $"
+__revision__ = "$Revision: 66988 $"
 
 __all__ = ["OutputBuffer", "OutputBufferEvent", "ProcessBufferMixin",
-           "ProcessThread", "TaskThread", "OPB_STYLE_DEFAULT", "OPB_STYLE_INFO",
+           "ProcessThreadBase", "ProcessThread", "TaskThread", 
+           "OPB_STYLE_DEFAULT", "OPB_STYLE_INFO",
            "OPB_STYLE_WARN", "OPB_STYLE_ERROR", "OPB_STYLE_MAX",
 
            "OPB_ERROR_NONE", "OPB_ERROR_INVALID_COMMAND",
@@ -660,58 +661,26 @@ class ProcessBufferMixin:
 
 #-----------------------------------------------------------------------------#
 
-class ProcessThread(threading.Thread):
-    """Run a subprocess in a separate thread. Thread posts events back
-    to parent object on main thread for processing in the ui.
-    @see: EVT_PROCESS_START, EVT_PROCESS_END, EVT_UPDATE_TEXT
+class ProcessThreadBase(threading.Thread):
+    """Base Process Thread
+    Override DoPopen in subclasses.
 
     """
-    def __init__(self, parent, command, fname='',
-                 args=list(), cwd=None, env=dict(),
-                 use_shell=True):
-        """Initialize the ProcessThread object
-        Example:
-          >>> myproc = ProcessThread(myframe, '/usr/local/bin/python',
-                                     'hello.py', '--version', '/Users/me/home/')
-          >>> myproc.start()
-
-        @param parent: Parent Window/EventHandler to receive the events
-                       generated by the process.
-        @param command: Command string to execute as a subprocess.
-        @keyword fname: Filename or path to file to run command on.
-        @keyword args: Argument list or string to pass to use with fname arg.
-        @keyword cwd: Directory to execute process from or None to use current
-        @keyword env: Environment to run the process in (dictionary) or None to
-                      use default.
-        @keyword use_shell: Specify whether a shell should be used to launch 
-                            program or run directly
-
-        """
-        super(ProcessThread, self).__init__()
-
-        if isinstance(args, list):
-            args = u' '.join([arg.strip() for arg in args])
+    def __init__(self, parent):
+        super(ProcessThreadBase, self).__init__()
 
         # Attributes
         self.abort = False          # Abort Process
-        self._proc = None           # Process handle
+        self._proc = None
         self._parent = parent       # Parent Window/Event Handler
-        self._cwd = cwd             # Path at which to run from
-        self._cmd = dict(cmd=command, file=fname, args=args)
-        self._use_shell = use_shell
         self._sig_abort = signal.SIGTERM    # default signal to kill process
+        self._last_cmd = u""        # Last run command
 
-        # Make sure the environment is sane it must be all strings
-        nenv = dict(env) # make a copy to manipulate
-        for k, v in env.iteritems():
-            if isinstance(v, types.UnicodeType):
-                nenv[k] = v.encode(sys.getfilesystemencoding())
-            elif not isinstance(v, basestring):
-                nenv.pop(k)
-        self._env = nenv
-
-        # Setup
-        self.setDaemon(True)
+    #---- Properties ----#
+    LastCommand = property(lambda self: self._last_cmd,
+                           lambda self, val: setattr(self, '_last_cmd', val)) 
+    Parent = property(lambda self: self._parent)
+    Process = property(lambda self: self._proc)
 
     def __DoOneRead(self):
         """Read one line of output and post results.
@@ -737,7 +706,7 @@ class ProcessThread(threading.Thread):
                     else:
                         # Process has Exited
                         return False
-            except ValueError:
+            except ValueError, msg:
                 return False
             except (subprocess.pywintypes.error, Exception), msg:
                 if msg[0] in (109, errno.ESHUTDOWN):
@@ -828,12 +797,124 @@ class ProcessThread(threading.Thread):
         self._sig_abort = sig
         self.abort = True
 
+    def DoPopen(self):
+        """Open the process
+        Override in a subclass to implement custom process opening
+        @return: subprocess.Popen instance
+
+        """
+        raise NotImplementedError("Must implement DoPopen in subclasses!")
+
     def run(self):
         """Run the process until finished or aborted. Don't call this
         directly instead call self.start() to start the thread else this will
         run in the context of the current thread.
         @note: overridden from Thread
 
+        """
+        err = None
+        try:
+            self._proc = self.DoPopen()
+        except OSError, msg:
+            # NOTE: throws WindowsError on Windows which is a subclass of
+            #       OSError, so it will still get caught here.
+            err =  OutputBufferEvent(edEVT_PROCESS_ERROR,
+                                     self.Parent.GetId(),
+                                     OPB_ERROR_INVALID_COMMAND)
+            err.SetErrorMessage(msg)
+
+        evt = OutputBufferEvent(edEVT_PROCESS_START,
+                                self.Parent.GetId(),
+                                self.LastCommand)
+        wx.PostEvent(self.Parent, evt)
+
+        # Read from stdout while there is output from process
+        while not err and True:
+            if self.abort:
+                self.__KillPid(self.Process.pid)
+                self.__DoOneRead()
+                more = False
+                break
+            else:
+                more = False
+                try:
+                    more = self.__DoOneRead()
+                except wx.PyDeadObjectError:
+                    # Our parent window is dead so kill process and return
+                    self.__KillPid(self.Process.pid)
+                    return
+
+                if not more:
+                    break
+
+        # Notify of error in running the process
+        if err is not None:
+            wx.PostEvent(self.Parent, err)
+            result = -1
+        else:
+            try:
+                result = self.Process.wait()
+            except OSError:
+                result = -1
+
+        # Notify that process has exited
+        # Pack the exit code as the events value
+        evt = OutputBufferEvent(edEVT_PROCESS_EXIT, self.Parent.GetId(), result)
+        wx.PostEvent(self.Parent, evt)
+
+class ProcessThread(ProcessThreadBase):
+    """Run a subprocess in a separate thread. Thread posts events back
+    to parent object on main thread for processing in the ui.
+    @see: EVT_PROCESS_START, EVT_PROCESS_END, EVT_UPDATE_TEXT
+
+    """
+    def __init__(self, parent, command, fname='',
+                 args=list(), cwd=None, env=dict(),
+                 use_shell=True):
+        """Initialize the ProcessThread object
+        Example:
+          >>> myproc = ProcessThread(myframe, '/usr/local/bin/python',
+                                     'hello.py', '--version', '/Users/me/home/')
+          >>> myproc.start()
+
+        @param parent: Parent Window/EventHandler to receive the events
+                       generated by the process.
+        @param command: Command string to execute as a subprocess.
+        @keyword fname: Filename or path to file to run command on.
+        @keyword args: Argument list or string to pass to use with fname arg.
+        @keyword cwd: Directory to execute process from or None to use current
+        @keyword env: Environment to run the process in (dictionary) or None to
+                      use default.
+        @keyword use_shell: Specify whether a shell should be used to launch 
+                            program or run directly
+
+        """
+        super(ProcessThread, self).__init__(parent)
+
+        if isinstance(args, list):
+            args = u' '.join([arg.strip() for arg in args])
+
+        # Attributes
+        self._cwd = cwd             # Path at which to run from
+        self._cmd = dict(cmd=command, file=fname, args=args)
+        self._use_shell = use_shell
+
+        # Make sure the environment is sane it must be all strings
+        nenv = dict(env) # make a copy to manipulate
+        for k, v in env.iteritems():
+            if isinstance(v, types.UnicodeType):
+                nenv[k] = v.encode(sys.getfilesystemencoding())
+            elif not isinstance(v, basestring):
+                nenv.pop(k)
+        self._env = nenv
+
+        # Setup
+        self.setDaemon(True)
+
+    def DoPopen(self):
+        """Open the process
+        @return: subprocess.Popen instance
+
         """
         # using shell, Popen will need a string, else it must be a sequence
         # use shlex for complex command line tokenization/parsing
@@ -873,61 +954,15 @@ class ProcessThread(threading.Thread):
         else:
             suinfo = None
         
-        err = None
-        try:
-            self._proc = subprocess.Popen(command,
-                                          stdout=subprocess.PIPE,
-                                          stderr=subprocess.STDOUT,
-                                          shell=use_shell,
-                                          cwd=self._cwd,
-                                          env=self._env,
-                                          startupinfo=suinfo)
-        except OSError, msg:
-            # NOTE: throws WindowsError on Windows which is a subclass of
-            #       OSError, so it will still get caught here.
-            err =  OutputBufferEvent(edEVT_PROCESS_ERROR,
-                                     self._parent.GetId(),
-                                     OPB_ERROR_INVALID_COMMAND)
-            err.SetErrorMessage(msg)
-
-        evt = OutputBufferEvent(edEVT_PROCESS_START,
-                                self._parent.GetId(),
-                                command)
-        wx.PostEvent(self._parent, evt)
-
-        # Read from stdout while there is output from process
-        while not err and True:
-            if self.abort:
-                self.__KillPid(self._proc.pid)
-                self.__DoOneRead()
-                more = False
-                break
-            else:
-                more = False
-                try:
-                    more = self.__DoOneRead()
-                except wx.PyDeadObjectError:
-                    # Our parent window is dead so kill process and return
-                    self.__KillPid(self._proc.pid)
-                    return
-
-                if not more:
-                    break
-
-        # Notify of error in running the process
-        if err is not None:
-            wx.PostEvent(self._parent, err)
-            result = -1
-        else:
-            try:
-                result = self._proc.wait()
-            except OSError:
-                result = -1
-
-        # Notify that process has exited
-        # Pack the exit code as the events value
-        evt = OutputBufferEvent(edEVT_PROCESS_EXIT, self._parent.GetId(), result)
-        wx.PostEvent(self._parent, evt)
+        proc = subprocess.Popen(command,
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.STDOUT,
+                                shell=use_shell,
+                                cwd=self._cwd,
+                                env=self._env,
+                                startupinfo=suinfo)
+        self.LastCommand = command # Set last run command
+        return proc
 
     def SetArgs(self, args):
         """Set the args to pass to the command
