@@ -16,8 +16,8 @@ displaying a L{LogViewer} in the Shelf.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_log.py 66482 2010-12-28 21:57:50Z CJP $"
-__revision__ = "$Revision: 66482 $"
+__svnid__ = "$Id: ed_log.py 66909 2011-02-16 19:12:23Z CJP $"
+__revision__ = "$Revision: 66909 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -97,7 +97,7 @@ class LogViewer(eclib.ControlBox):
 
     """
     def __init__(self, parent):
-        eclib.ControlBox.__init__(self, parent)
+        super(LogViewer, self).__init__(parent)
 
         # Attributes
         self._buffer = LogBuffer(self)
@@ -124,9 +124,7 @@ class LogViewer(eclib.ControlBox):
     def __DoLayout(self):
         """Layout the log viewer window"""
         # Setup ControlBar
-        ctrlbar = eclib.ControlBar(self, style=eclib.CTRLBAR_STYLE_GRADIENT)
-        if wx.Platform == '__WXGTK__':
-            ctrlbar.SetWindowStyle(eclib.CTRLBAR_STYLE_DEFAULT)
+        ctrlbar = self.CreateControlBar(wx.TOP)
 
         # View Choice
         self._srcfilter = wx.Choice(ctrlbar, wx.ID_ANY, choices=[])
@@ -140,10 +138,9 @@ class LogViewer(eclib.ControlBox):
         if cbmp.IsNull() or not cbmp.IsOk():
             cbmp = None
         clear = eclib.PlateButton(ctrlbar, wx.ID_CLEAR, _("Clear"),
-                                     cbmp, style=eclib.PB_STYLE_NOBG)
+                                  cbmp, style=eclib.PB_STYLE_NOBG)
         ctrlbar.AddControl(clear, wx.ALIGN_RIGHT)
-        ctrlbar.SetVMargin(1, 1)
-        self.SetControlBar(ctrlbar)
+        ctrlbar.SetVMargin(0, 0)
         
     def OnChoice(self, evt):
         """Set the filter based on the choice controls value
@@ -185,7 +182,7 @@ class LogBuffer(eclib.OutputBuffer):
     ERROR_STYLE = eclib.OPB_STYLE_MAX + 1
 
     def __init__(self, parent):
-        eclib.OutputBuffer.__init__(self, parent)
+        super(LogBuffer, self).__init__(parent)
 
         # Attributes
         self._filter = SHOW_ALL_MSG
@@ -210,7 +207,7 @@ class LogBuffer(eclib.OutputBuffer):
     def OnDestroy(self, evt):
         """Unregister from receiving any more log messages"""
         if evt.GetId() == self.GetId():
-            ed_msg.Unsubscribe(self.UpdateLog, ed_msg.EDMSG_LOG_ALL)
+            ed_msg.Unsubscribe(self.UpdateLog)
         evt.Skip()
 
     def AddFilter(self, src):
