@@ -15,11 +15,11 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 66685 2011-01-14 23:10:50Z CJP $"
-__revision__ = "$Revision: 66685 $"
+__svnid__ = "$Id: ed_main.py 67027 2011-02-25 21:04:49Z CJP $"
+__revision__ = "$Revision: 67027 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Dependencies
 import os
 import sys
 import time
@@ -94,6 +94,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Attributes
         self._loaded = False
+        self._initialized = False # for GTK OnActivate HACK
         self._mlock = ebmlib.CallLock()
         self._last_save = u''
         self.LOG = wx.GetApp().GetLog()
@@ -101,12 +102,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._handlers = dict(menu=list(), ui=list())
 
         #---- Setup File History ----#
-        self.filehistory = wx.FileHistory(_PGET('FHIST_LVL', 'int', 9))
+        self.filehistory = ebmlib.EFileHistory(_PGET('FHIST_LVL', 'int', 9))
 
         #---- Status bar on bottom of window ----#
         self.SetStatusBar(ed_statbar.EdStatBar(self))
         self.GetStatusBar().Show(_PGET('STATBAR', default=True))
-
         #---- End Statusbar Setup ----#
 
         #---- Notebook that contains the editing buffers ----#
@@ -129,8 +129,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             MainWindow.PRINTER = ed_print.EdPrinter(self)
 
         #---- Setup Toolbar ----#
-        self.SetToolBar(ed_toolbar.EdToolBar(self))
-        self.GetToolBar().Show(_PGET('TOOLBAR'))
+        self.SetupToolBar()
         #---- End Toolbar Setup ----#
 
         #---- Menus ----#
@@ -180,6 +179,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_COLUMN_MODE, self.DispatchToControl),
                                        (ID_TOGGLE_FOLD, self.DispatchToControl),
                                        (ID_TOGGLE_ALL_FOLDS, self.DispatchToControl),
+                                       (ID_SHOW_AUTOCOMP, self.DispatchToControl),
+                                       (ID_SHOW_CALLTIP, self.DispatchToControl),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -300,6 +301,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Set Perspective and other UI settings
         self.SetPerspective(_PGET('DEFAULT_VIEW'))
         self._mgr.Update()
+        # TODO: this callback is no longer necessary due to the
+        #       profile notifier callbacks.
         ed_msg.PostMessage(ed_msg.EDMSG_DSP_FONT,
                            _PGET('FONT3', 'font', wx.NORMAL_FONT))
 
@@ -313,6 +316,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     __name__ = u"MainWindow"
 
     def OnDestroy(self, evt):
+        """Disconnect Message Handlers"""
         if evt.GetId() == self.GetId():
             ed_msg.Unsubscribe(self.OnUpdateFileHistory)
         evt.Skip()
@@ -355,7 +359,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             #      window doesn't get activated until later than it does on the
             #      other platforms. So for panels that depend on updating their
             #      initial state we need to send out a fake update message here.
-            if wx.Platform == '__WXGTK__':
+            if wx.Platform == '__WXGTK__' and not self._initialized:
+                self._initialized = True
                 nb = self.GetNotebook()
                 ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED,
                                    (nb, nb.GetSelection()))
@@ -560,18 +565,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             hist_list = _PGET('FHIST', default=list())
             if len(hist_list) > size:
                 hist_list = hist_list[:size]
-
-            for fname in hist_list:
-                if isinstance(fname, basestring) and fname:
-                    # TODO: find out why these errors are happening
-                    #       when loading the pickled strings on some systems
-                    #       The pickled strings are not in unicode format.
-                    try:
-                        self.filehistory.AddFileToHistory(fname)
-                    except wx.PyAssertionError:
-                        pass
+            self.filehistory.History = hist_list
         except UnicodeEncodeError, msg:
-            self.LOG("[ed_main][err] Filehistory load failed: %s" % str(msg))
+            self.LOG("[ed_main][err] Filehistory load failed: %s" % msg)
 
     def OnNew(self, evt):
         """Start a New File in a new tab
@@ -899,17 +895,20 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._exiting = True
         controls = self.nb.GetPageCount()
         self.LOG("[ed_main][evt] OnClose: Number of controls: %d" % controls)
+        self.Freeze()
         while controls:
             if controls <= 0:
                 self.Close(True) # Force exit since there is a problem
 
             self.LOG("[ed_main][evt] OnClose: Requesting Page Close")
             if not self.nb.ClosePage():
+                self.Thaw()
                 self._exiting = False
                 ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED,
                                    (self.nb, self.nb.GetSelection()))
                 return True
             controls -= 1
+        self.Thaw()
 
         ### If we get to here there is no turning back so cleanup
         ### additional items and save user settings
@@ -920,6 +919,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Save Shelf contents
         _PSET('SHELF_ITEMS', self._shelf.GetItemStack())
+        _PSET('SHELF_LAYOUT', self._shelf.GetPerspective())
+        _PSET('SHELF_SELECTION', self._shelf.GetSelection())
 
         # Save Window Size/Position for next launch
         self.UpdateAutoPerspective()
@@ -945,8 +946,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # TODO: Find out why filehistory can be undefined by this point
         #       sometimes.
         try:
-            profiler.AddFileHistoryToProfile(self.filehistory)
-            del self.filehistory
+            _PSET('FHIST', self.filehistory.History)
         except AttributeError:
             self.LOG("[ed_main][err] OnClose: Trapped AttributeError OnExit")
 
@@ -1136,7 +1136,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
                         ID_PASTE_AFTER, ID_COLUMN_MODE, ID_TOGGLE_FOLD,
                         ID_CYCLE_CLIPBOARD,
-                        ID_TOGGLE_ALL_FOLDS, ID_DELETE_LINE ]
+                        ID_TOGGLE_ALL_FOLDS, ID_DELETE_LINE,
+                        ID_SHOW_AUTOCOMP, ID_SHOW_CALLTIP ]
 
         # Special handling for common clipboard related actions
         has_focus = self.FindFocus()
@@ -1239,6 +1240,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 if not success:
                     msg = _("Failed to reload the file with: %(encoding)s") % dict(encoding=nenc)
                     wx.MessageBox(msg, style=wx.OK|wx.ICON_ERROR)
+                    # Revert to previous encoding
                     doc.SetEncoding(cenc)
                     ctrl.ReloadFile()
             dlg.Destroy()
@@ -1530,6 +1532,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             name = " - " + name
         wx.Frame.SetTitle(self, title + name)
 
+    def SetupToolBar(self):
+        """Setup or reinitialize the windows ToolBar"""
+        tb = self.GetToolBar()
+        if tb:
+            tb.Destroy()
+        self.SetToolBar(ed_toolbar.EdToolBar(self))
+        self.GetToolBar().Show(_PGET('TOOLBAR'))
+        self.Layout()
+
     @classmethod
     def UpdateClipboardRing(cls):
         """Update the clipboard ring to sync it with the
