@@ -13,12 +13,13 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 66686 2011-01-14 23:13:08Z CJP $"
-__revision__ = "$Revision: 66686 $"
+__svnid__ = "$Id: ed_pages.py 67027 2011-02-25 21:04:49Z CJP $"
+__revision__ = "$Revision: 67027 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
 import os
+import sys
 import glob
 import cPickle
 import wx
@@ -62,7 +63,8 @@ class EdPages(aui.AuiNotebook):
                 aui.AUI_NB_USE_IMAGES_DROPDOWN | \
                 aui.AUI_NB_TAB_EXTERNAL_MOVE | \
                 aui.AUI_NB_TAB_FIXED_WIDTH | \
-                aui.AUI_NB_ORDER_BY_ACCESS
+                aui.AUI_NB_ORDER_BY_ACCESS | \
+                aui.AUI_NB_NO_TAB_FOCUS
         if wx.Platform == '__WXMAC__':
             style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
         super(EdPages, self).__init__(parent, id_num, agwStyle=style)
@@ -103,6 +105,7 @@ class EdPages(aui.AuiNotebook):
         # Set custom options
         self.SetSashDClickUnsplit(True)
         self.SetMinMaxTabWidth(125, 135)
+        self.UpdateFontSetting()
 
         # Notebook Events
         self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
@@ -129,6 +132,8 @@ class EdPages(aui.AuiNotebook):
         ed_msg.Subscribe(self.OnUpdatePosCache, ed_msg.EDMSG_UI_STC_POS_JUMPED)
         ed_msg.RegisterCallback(self.OnDocPointerRequest,
                                 ed_msg.EDREQ_DOCPOINTER)
+        ed_msg.Subscribe(self.OnConfigMsg,
+                         ed_msg.EDMSG_PROFILE_CHANGE + ('FONT3',))
 
         # Add a blank page
         self.NewPage()
@@ -140,6 +145,7 @@ class EdPages(aui.AuiNotebook):
         if evt.GetId() == self.GetId():
             ed_msg.Unsubscribe(self.OnThemeChanged)
             ed_msg.Unsubscribe(self.OnUpdatePosCache)
+            ed_msg.Unsubscribe(self.OnConfigMsg)
             ed_msg.UnRegisterCallback(self.OnDocPointerRequest)
 
     #---- Function Definitions ----#
@@ -347,7 +353,7 @@ class EdPages(aui.AuiNotebook):
 
         if os.path.exists(session):
             try:
-                f_handle = open(session)
+                f_handle = open(session, 'rb')
             except IOError:
                 f_handle = None
         else:
@@ -385,6 +391,11 @@ class EdPages(aui.AuiNotebook):
         missingfns = []
         for loadfn in flist:
             if os.path.exists(loadfn) and os.access(loadfn, os.R_OK):
+                if not ebmlib.IsUnicode(loadfn):
+                    try:
+                        loadfn = loadfn.decode(sys.getfilesystemencoding())
+                    except UnicodeDecodeError:
+                        self.LOG("[ed_pages][err] LoadSessionFile: Failed to decode file name")
                 self.OpenPage(os.path.dirname(loadfn),
                               os.path.basename(loadfn))
             else:
@@ -577,6 +588,19 @@ class EdPages(aui.AuiNotebook):
         """
         self.UpdateAllImages()
 
+    def OnConfigMsg(self, msg):
+        """Handle configuration change updates"""
+        mtype = msg.GetType()[-1]
+        if mtype == 'FONT3':
+            # UI display font has changed
+            self.UpdateFontSetting()
+
+    def UpdateFontSetting(self):
+        """Update font setting using latest profile data"""
+        font = Profile_Get('FONT3', 'font', None)
+        if font:
+            self.SetFont(font)
+
     def OnUpdatePosCache(self, msg):
         """Update the position cache for buffer position changes
         @param msg: message data
@@ -909,10 +933,14 @@ class EdPages(aui.AuiNotebook):
 
         """
         bReadOnly = False
-        if index < self.GetPageCount():
-            bReadOnly = self.GetPageImage(index) == self._index[ed_glob.ID_READONLY]
-        else:
-            self.LOG("[ed_pages][warn] ImageIsReadOnly: Bad index: %d" % index)
+        try:
+            if index < self.GetPageCount():
+                bReadOnly = self.GetPageImage(index) == self._index[ed_glob.ID_READONLY]
+            else:
+                self.LOG("[ed_pages][warn] ImageIsReadOnly: Bad index: %d" % index)
+        except Exception, msg:
+            # TODO: investigate possible upstream issue
+            self.LOG("[ed_pages][err] ImageIsReadOnly: %s" % msg)
         return bReadOnly
 
     def SetPageText(self, pg_num, txt):
@@ -1144,9 +1172,6 @@ class EdPages(aui.AuiNotebook):
         @return bool: was page deleted?
 
         """
-        frame = self.GetTopLevelParent()
-
-        frame.Freeze()
         try:
             page = self.GetPage(idx)
             result = page.CanCloseTab()
@@ -1159,7 +1184,9 @@ class EdPages(aui.AuiNotebook):
                                            SIMULATED_EVT_ID)
                 evt.SetSelection(idx)
                 self.OnPageClosing(evt)
+                self.TopLevelParent.Freeze() # prevent flashing on OSX
                 self.DeletePage(idx)
+                self.TopLevelParent.Thaw()
                 evt = aui.AuiNotebookEvent(aui.wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSED,
                                            SIMULATED_EVT_ID)
                 evt.SetSelection(idx)
@@ -1167,8 +1194,6 @@ class EdPages(aui.AuiNotebook):
         except Exception:
             # TODO: workaround for crash in base on destruction
             pass
-        finally:
-            frame.Thaw()
 
         return result
 
