@@ -14,8 +14,8 @@ Shelf plugin and control implementation
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_shelf.py 66490 2010-12-29 02:50:53Z CJP $"
-__revision__ = "$Revision: 66490 $"
+__svnid__ = "$Id: ed_shelf.py 66747 2011-01-24 21:25:00Z CJP $"
+__revision__ = "$Revision: 66747 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -128,6 +128,8 @@ class Shelf(plugin.Plugin):
                 observer.InstallComponents(parent)
 
         delegate.StockShelf(Profile_Get('SHELF_ITEMS', 'list', []))
+        delegate.SetPerspective(Profile_Get('SHELF_LAYOUT', 'str', u""))
+        delegate.SetSelection(Profile_Get('SHELF_SELECTION', 'int', -1))
         return delegate
 
 #--------------------------------------------------------------------------#
@@ -140,7 +142,8 @@ class EdShelfBook(aui.AuiNotebook):
                 aui.AUI_NB_SCROLL_BUTTONS | \
                 aui.AUI_NB_CLOSE_ON_ACTIVE_TAB | \
                 aui.AUI_NB_TAB_MOVE | \
-                aui.AUI_NB_DRAW_DND_TAB
+                aui.AUI_NB_DRAW_DND_TAB | \
+                aui.AUI_NB_NO_TAB_FOCUS
         if wx.Platform == '__WXMAC__':
             style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
         super(EdShelfBook, self).__init__(parent, agwStyle=style)
@@ -362,6 +365,28 @@ class EdShelfDelegate(object):
                             self._shelf.GetPageText(page), 1))
         return rval
 
+    def GetSelection(self):
+        """Get the index of the currently selected tab"""
+        if self._shelf:
+            return self._shelf.GetSelection()
+        return -1
+
+    def GetPerspective(self):
+        """Get the auinotebook perspective data
+        @return: string
+
+        """
+        return self._shelf.SavePerspective()
+
+    def SetPerspective(self, pdata):
+        """Set the aui notebooks perspective and layout
+        @param pdata: perspective data string
+
+        """
+        if pdata:
+            self._shelf.LoadPerspective(pdata)
+            self._shelf.Update()
+
     def GetMenu(self):
         """Return the menu of this object
         @return: ed_menu.EdMenu()
@@ -504,6 +529,14 @@ class EdShelfDelegate(object):
         else:
             return None
 
+    def SetSelection(self, index):
+        """Select an item in the Shelf window
+        @param index: shelf tab index
+
+        """
+        if self._shelf and index > 0 and index < self._shelf.GetPageCount():
+            self._shelf.SetSelection(index)
+
     def StockShelf(self, i_list):
         """Fill the shelf by opening an ordered list of items
         @param i_list: List of named L{ShelfI} instances
