@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 66529 2011-01-03 03:09:57Z CJP $"
-__revision__ = "$Revision: 66529 $"
+__svnid__ = "$Id: ed_stc.py 67034 2011-02-26 18:30:53Z CJP $"
+__revision__ = "$Revision: 67034 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -341,17 +341,22 @@ class EditraStc(ed_basestc.EditraBaseStc):
         else:
             wx.CallAfter(self.BraceHighlight, brace_at_caret, brace_opposite)
 
-    def GetBracePair(self):
+    def GetBracePair(self, pos=-1):
         """Get a tuple of the positions in the buffer where the brace at the
         current caret position and its match are. if a brace doesn't have a
         match it will return -1 for the missing brace.
+        @keyword pos: -1 to use current cursor pos, else use to specify brace pos
         @return: tuple (brace_at_caret, brace_opposite)
 
         """
         brace_at_caret = -1
         brace_opposite = -1
         char_before = None
-        caret_pos = self.GetCurrentPos()
+        if pos < 0:
+            # use current position
+            caret_pos = self.GetCurrentPos()
+        else:
+            caret_pos = pos
 
         if caret_pos > 0:
             char_before = self.GetCharAt(caret_pos - 1)
@@ -694,32 +699,15 @@ class EditraStc(ed_basestc.EditraBaseStc):
             if self._config['autocomp']:
                 self.ShowAutoCompOpt(command)
 
-        elif cmpl.IsAutoCompEvent(evt):
-            if self.AutoCompActive():
-                self.AutoCompCancel()
-
-            command = self.GetCommandStr()
-            if self._config['autocomp']:
-                self.ShowAutoCompOpt(command)
-
         elif key_code in cmpl.GetCallTipKeys():
-            if self.AutoCompActive():
-                self.AutoCompCancel()
-
-            command = self.GetCommandStr()
+            self.HidePopups()
             uchr = unichr(key_code)
+            command = self.GetCommandStr() + uchr
             self.PutText(uchr)
 
             if self._config['autocomp']:
                 self.ShowCallTip(command)
 
-        elif cmpl.IsCallTipEvent(evt):
-            if self.AutoCompActive():
-                self.AutoCompCancel()
-            command = self.GetCommandStr()
-            if self._config['autocomp']:
-                self.ShowCallTip(command[:command.rfind('(')])
-
         elif key_code in cmpl.GetCallTipCancel():
             evt.Skip()
             self.CallTipCancel()
@@ -731,6 +719,21 @@ class EditraStc(ed_basestc.EditraBaseStc):
 #            print "IS TAB", key_code, wx.WXK_TAB
             evt.Skip()
 
+    def DoAutoComplete(self):
+        """Atempt to perform an autocompletion event."""
+        self.HidePopups()
+        if self._config['autocomp']:
+            command = self.GetCommandStr()
+            self.ShowAutoCompOpt(command)
+
+    def DoCallTip(self):
+        """Attempt to show a calltip for the current cursor position"""
+        self.HidePopups()
+        if self._config['autocomp']:
+            command = self.GetCommandStr()
+            # TODO: GetCommandStr seems to be inadquate under some cases
+            self.ShowCallTip(command)
+
     def OnKeyUp(self, evt):
         """Update status bar of window
         @param evt: wxEVT_KEY_UP
@@ -880,7 +883,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         # when the mouse has not dwelled within the buffer area
         mpoint = wx.GetMousePosition()
         brect = self.GetScreenRect()
-        if not brect.Contains(mpoint):
+        if not brect.Contains(mpoint) or not self.IsShown():
             return
 
         position = evt.Position
@@ -923,7 +926,8 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @type evt: wx.stc.StyledTextEvent
 
         """
-        if evt.GetMargin() == ed_basestc.FOLD_MARGIN:
+        margin_num = evt.GetMargin()
+        if margin_num == ed_basestc.FOLD_MARGIN:
             if evt.GetShift() and \
                (evt.GetControl() or (wx.Platform == '__WXMAC__' and evt.GetAlt())):
                 self.FoldAll()
@@ -950,12 +954,17 @@ class EditraStc(ed_basestc.EditraBaseStc):
                             self.Expand(line_clicked, True, True, 100, level)
                     else:
                         self.ToggleFold(line_clicked)
-        elif evt.GetMargin() == ed_basestc.MARK_MARGIN:
+        elif margin_num == ed_basestc.MARK_MARGIN:
             # Bookmarks ect...
             line_clicked = self.LineFromPosition(evt.GetPosition())
-            if self.MarkerGet(line_clicked):
+            marker = self.MarkerGet(line_clicked)
+            if marker & (1<<ed_basestc.MARKER_BOOKMARK):
                 self.RemoveBookmark(line_clicked)
+            elif marker & (1<<ed_basestc.MARKER_BREAKPOINT):
+                # TODO: callback for plugins that set breakpoint?
+                self.DeleteBreakpoint(line_clicked)
             else:
+                # TODO: add callback to allow plugin to set callback
                 self.AddBookmark(line_clicked)
 
     def FoldAll(self):
@@ -967,7 +976,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         expanding = True
 
         # find out if we are folding or unfolding
-        for line_num in xrange(line_count):
+        for line_num in range(line_count):
             if self.GetFoldLevel(line_num) & wx.stc.STC_FOLDLEVELHEADERFLAG:
                 expanding = not self.GetFoldExpanded(line_num)
                 break
@@ -1085,7 +1094,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
                   ed_glob.ID_MACRO_START : self.StartRecord,
                   ed_glob.ID_MACRO_STOP : self.StopRecord,
                   ed_glob.ID_MACRO_PLAY : self.PlayMacro,
-                  ed_glob.ID_GOTO_MBRACE : self.GotoBraceMatch
+                  ed_glob.ID_GOTO_MBRACE : self.GotoBraceMatch,
+                  ed_glob.ID_SHOW_AUTOCOMP : self.DoAutoComplete,
+                  ed_glob.ID_SHOW_CALLTIP : self.DoCallTip
         }
 
         e_idmap = { ed_glob.ID_ZOOM_OUT : self.DoZoom,
@@ -1802,13 +1813,23 @@ class EditraStc(ed_basestc.EditraBaseStc):
                 marks = self.GetBookmarks()
                 cpos = self.GetCurrentPos()
                 # TODO: Handle async re-loads of large files
-                self.SetText(self.File.Read())
+                txt = self.File.Read()
+                self.SetReadOnly(False)
+                if txt is not None:
+                    if self.File.IsRawBytes() and not ebmlib.IsUnicode(txt):
+                        self.AddStyledText(txt)
+                        self.SetReadOnly(True) # Don't allow editing of raw bytes
+                    else:
+                        self.SetText(txt)
+                else:
+                    return False, _("Failed to reload: %s") % cfile
+
                 self.SetModTime(ebmlib.GetFileModTime(cfile))
                 for mark in marks:
                     self.AddBookmark(mark)
                 self.EndUndoAction()
                 self.SetSavePoint()
-            except (AttributeError, OSError, IOError), msg:
+            except (UnicodeDecodeError, AttributeError, OSError, IOError), msg:
                 self.LOG("[ed_stc][err] Failed to Reload %s" % cfile)
                 return False, msg
             else:
