@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 66482 2010-12-28 21:57:50Z CJP $"
-__revision__ = "$Revision: 66482 $"
+__svnid__ = "$Id: prefdlg.py 67027 2011-02-25 21:04:49Z CJP $"
+__revision__ = "$Revision: 67027 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -39,6 +39,7 @@ import updater
 import util
 import syntax.syntax as syntax
 import ed_msg
+import ed_txt
 import eclib
 import extern.stcspellcheck as stcspellcheck
 
@@ -485,7 +486,7 @@ class GeneralFilePanel(wx.Panel):
         # Encoding options
         d_encoding = Profile_Get('ENCODING',
                                  'str',
-                                 default=locale.getpreferredencoding())
+                                 default=ed_txt.DEFAULT_ENCODING)
         if d_encoding is None:
             d_encoding = 'utf-8'
             Profile_Set('ENCODING', d_encoding)
@@ -1309,6 +1310,8 @@ class AppearancePanel(wx.Panel, PreferencesPanelBase):
         font = evt.GetValue()
         if isinstance(font, wx.Font) and not font.IsNull():
             Profile_Set('FONT3', font, 'font')
+            # TODO: this callback is no longer necessary due to the
+            #       profile notifier callbacks.
             ed_msg.PostMessage(ed_msg.EDMSG_DSP_FONT, font)
 
     @staticmethod
@@ -1519,7 +1522,7 @@ class UpdatePage(wx.Panel):
         upd_box = wx.StaticBox(self, label=_("Latest Version"))
         upd_bsz = wx.StaticBoxSizer(upd_box, wx.HORIZONTAL)
         upd_bsz.SetMinSize(wx.Size(150, 40))
-        upd_bsz.Add(wx.StaticText(self, ID_UPDATE_MSG, _(e_update.GetStatus())),
+        upd_bsz.Add(wx.StaticText(self, ID_UPDATE_MSG, _("Status Unknown")),
                     0, wx.ALIGN_CENTER_HORIZONTAL)
         upd_bsz.Layout()
 
@@ -1560,6 +1563,7 @@ class UpdatePage(wx.Panel):
         if e_id == ID_CHECK_UPDATE:
             util.Log("[prefdlg][evt] Update Page: Check Update Clicked")
             e_obj.Disable()
+            self.FindWindowById(ID_UPDATE_MSG).SetLabel(_("Checking..."))
             prog_bar = self.FindWindowById(ed_glob.ID_PREF_UPDATE_BAR)
             # Note this function returns right away but its result is
             # handled on a separate thread. This window is then notified
@@ -1593,6 +1597,10 @@ class UpdatePage(wx.Panel):
         nbevt = wx.NotebookEvent(wx.wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGED,
                                  0, curr_pg, curr_pg)
         wx.PostEvent(self.GetParent(), nbevt)
+        gauge = self.FindWindowById(ed_glob.ID_PREF_UPDATE_BAR)
+        if gauge:
+            gauge.Stop()
+            gauge.SetValue(100)
         self.Refresh()
 
 #-----------------------------------------------------------------------------#
@@ -1647,9 +1655,9 @@ ID_BINDING = wx.NewId()
 KEYS = ['', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
         'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
         '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '-', '+', '/', ',',
-        '.', '[', ']', '{', '}', ':', 'Left', 'Right', 'Down', 'Up', 'Home',
-        'End', 'Enter', 'Tab']
-KEYS.extend(["F" + str(x) for x in range(1, 13)])
+        '.', '[', ']', '{', '}', '>', '<', ':', '|', 'Left', 'Right', 'Down',
+        'Up', 'Home', 'End', 'Enter', 'Tab', 'Space', '"', "'"]
+KEYS.extend(["F" + str(x) for x in range(1, 13)]) # Add function keys
 
 if wx.Platform == '__WXMSW__':
     KEYS.remove('Tab')
@@ -1668,6 +1676,7 @@ class KeyBindingPanel(wx.Panel):
         super(KeyBindingPanel, self).__init__(parent)
 
         # Attributes
+        self._dirty = False
         self.menub = wx.GetApp().GetActiveWindow().GetMenuBar()
         self.binder = self.menub.GetKeyBinder()
         self.menumap = dict()
@@ -1687,6 +1696,9 @@ class KeyBindingPanel(wx.Panel):
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CHOICE, self.OnChoice)
         self.Bind(wx.EVT_LISTBOX, self.OnListBox)
+        self.Bind(wx.EVT_UPDATE_UI,
+                  lambda evt: evt.Enable(self.Dirty),
+                  id=wx.ID_APPLY)
 
     def _DoLayout(self):
         """Layout the controls"""
@@ -1856,6 +1868,11 @@ class KeyBindingPanel(wx.Panel):
 
         self._UpdateBinding()
 
+    #---- Properties ----#
+
+    Dirty = property(lambda self: self._dirty,
+                     lambda self, bDirty: setattr(self, '_dirty', bDirty))
+
     def ClearKeyView(self):
         """Clear all selections in the keybinding controls"""
         self.FindWindowById(ID_MOD1).SetStringSelection('')
@@ -1990,8 +2007,10 @@ class KeyBindingPanel(wx.Panel):
                 mod2.SetItems(tmods)
                 mod2.SetStringSelection('')
             self._UpdateBinding()
+            self.Dirty = True
         elif e_id in [ID_MOD2, ID_KEYS]:
             self._UpdateBinding()
+            self.Dirty = True
         else:
             evt.Skip()
 
