@@ -7,12 +7,13 @@
 ###############################################################################
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: common.py 61520 2009-07-25 02:08:49Z CJP $"
-__revision__ = "$Revision: 61520 $"
+__svnid__ = "$Id: common.py 65204 2010-08-06 19:31:41Z CJP $"
+__revision__ = "$Revision: 65204 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
 import os
+import locale
 import shutil
 import wx
 
@@ -27,6 +28,7 @@ class EdApp(wx.App):
         self.pmgr = plugin.PluginManager()
 
         # Bare minimum profile bootstrap
+        profiler.Profile_Set('ENCODING', locale.getpreferredencoding())
         profiler.Profile_Set('ICONS', 'Tango')
 
         return True
@@ -39,6 +41,11 @@ class EdApp(wx.App):
 
 #-----------------------------------------------------------------------------#
 
+class TestFrame(wx.Frame):
+    pass
+
+#-----------------------------------------------------------------------------#
+
 def CleanTempDir():
     """Clean all files from the temporary directory"""
     tdir = GetTempDir()
@@ -69,6 +76,17 @@ def GetDataFilePath(fname):
     path = os.path.join(u'.', u'data', fname)
     return os.path.abspath(path)
 
+def GetFileContents(path):
+    """Get the contents of the given file
+    @param path: string
+    @return: string
+
+    """
+    handle = open(path, 'rb')
+    txt = handle.read()
+    handle.close()
+    return txt
+
 def GetTempDir():
     """Get the path to the test temp directory
     @return: string
@@ -77,6 +95,15 @@ def GetTempDir():
     path = os.path.join(u'.', u'temp')
     return os.path.abspath(path)
 
+def GetTempFilePath(fname):
+    """Get a path for a file in the temp directory
+    @param fname: File name to get path for
+    @return: string
+
+    """
+    tdir = GetTempDir()
+    return os.path.join(tdir, fname)
+
 def GetThemeDir():
     """Get the packages theme directory path
     @return: string
